package com.fs.doc.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.fs.doc.param.DocQueryParam;
import com.fs.doc.vo.DocListQueryVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.doc.mapper.DocMapper;
import com.fs.doc.domain.Doc;
import com.fs.doc.service.IDocService;

/**
 * 档案Service业务层处理
 * 
 * @author fs
 * @date 2023-01-09
 */
@Service
public class DocServiceImpl implements IDocService 
{
    @Autowired
    private DocMapper docMapper;

    /**
     * 查询档案
     * 
     * @param docId 档案ID
     * @return 档案
     */
    @Override
    public Doc selectDocById(Long docId)
    {
        return docMapper.selectDocById(docId);
    }

    /**
     * 查询档案列表
     * 
     * @param doc 档案
     * @return 档案
     */
    @Override
    public List<Doc> selectDocList(Doc doc)
    {
        return docMapper.selectDocList(doc);
    }

    /**
     * 新增档案
     * 
     * @param doc 档案
     * @return 结果
     */
    @Override
    public int insertDoc(Doc doc)
    {
        doc.setCreateTime(DateUtils.getNowDate());
        return docMapper.insertDoc(doc);
    }

    /**
     * 修改档案
     * 
     * @param doc 档案
     * @return 结果
     */
    @Override
    public int updateDoc(Doc doc)
    {
        doc.setUpdateTime(DateUtils.getNowDate());
        return docMapper.updateDoc(doc);
    }

    /**
     * 批量删除档案
     * 
     * @param docIds 需要删除的档案ID
     * @return 结果
     */
    @Override
    public int deleteDocByIds(Long[] docIds)
    {
        return docMapper.deleteDocByIds(docIds);
    }

    /**
     * 删除档案信息
     * 
     * @param docId 档案ID
     * @return 结果
     */
    @Override
    public int deleteDocById(Long docId)
    {
        return docMapper.deleteDocById(docId);
    }

    @Override
    public List<DocListQueryVO> selectDocListVOQuery(DocQueryParam param) {
        return docMapper.selectDocListVOQuery(param);
    }
}
